import os
import subprocess
import sys

def run_sut_with_testcases(sut_path, testcase_dir):
    # Check if SUT exists
    if not os.path.isfile(sut_path):
        print(f"Error: SUT not found at {sut_path}")
        return

    # Check if testcase directory exists
    if not os.path.isdir(testcase_dir):
        print(f"Error: Testcase directory not found at {testcase_dir}")
        return

    # Get all files in the testcase directory
    testcases = [f for f in os.listdir(testcase_dir) if os.path.isfile(os.path.join(testcase_dir, f))]

    # Run SUT with each testcase
    for testcase in testcases:
        testcase_path = os.path.join(testcase_dir, testcase)
        print(f"Running SUT with testcase: {testcase}")
        
        try:
            # Run the SUT as a subprocess
            result = subprocess.run([sut_path, testcase_path], 
                                    capture_output=True, 
                                    text=True, 
                                    timeout=30)  # 30 second timeout, adjust as needed
            
            # Print the output
            print("STDOUT:")
            print(result.stdout)
            print("STDERR:")
            print(result.stderr)
            print(f"Return code: {result.returncode}")
            
        except subprocess.TimeoutExpired:
            print(f"Execution timed out for testcase: {testcase}")
        except Exception as e:
            print(f"An error occurred while running testcase {testcase}: {str(e)}")
        
        print("-" * 50)  # Separator between testcases

if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("Usage: python run_tests.py <path_to_sut> <path_to_afl_testcase_directory>")
        sys.exit(1)
    
    sut_path = sys.argv[1]
    testcase_dir = sys.argv[2]
    
    run_sut_with_testcases(sut_path, testcase_dir)
